# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: src/ray/protobuf/gcs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as src_dot_ray_dot_protobuf_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='src/ray/protobuf/gcs.proto',
  package='ray.rpc',
  syntax='proto3',
  serialized_options=b'\n\030io.ray.runtime.generated',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1asrc/ray/protobuf/gcs.proto\x12\x07ray.rpc\x1a\x1dsrc/ray/protobuf/common.proto\"m\n\x08GcsEntry\x12\x37\n\x0b\x63hange_mode\x18\x01 \x01(\x0e\x32\x16.ray.rpc.GcsChangeModeR\nchangeMode\x12\x0e\n\x02id\x18\x02 \x01(\x0cR\x02id\x12\x18\n\x07\x65ntries\x18\x03 \x03(\x0cR\x07\x65ntries\"+\n\x0fObjectTableData\x12\x18\n\x07manager\x18\x01 \x01(\x0cR\x07manager\"\x8a\x01\n\x16TaskReconstructionData\x12\x17\n\x07task_id\x18\x01 \x01(\x0cR\x06taskId\x12/\n\x13num_reconstructions\x18\x02 \x01(\x04R\x12numReconstructions\x12&\n\x0fnode_manager_id\x18\x03 \x01(\x0cR\rnodeManagerId\"2\n\rTaskTableData\x12!\n\x04task\x18\x01 \x01(\x0b\x32\r.ray.rpc.TaskR\x04task\"\xfd\x07\n\x0e\x41\x63torTableData\x12\x19\n\x08\x61\x63tor_id\x18\x01 \x01(\x0cR\x07\x61\x63torId\x12\x1b\n\tparent_id\x18\x02 \x01(\x0cR\x08parentId\x12\x42\n\x1e\x61\x63tor_creation_dummy_object_id\x18\x03 \x01(\x0cR\x1a\x61\x63torCreationDummyObjectId\x12\x15\n\x06job_id\x18\x04 \x01(\x0cR\x05jobId\x12\x38\n\x05state\x18\x06 \x01(\x0e\x32\".ray.rpc.ActorTableData.ActorStateR\x05state\x12!\n\x0cmax_restarts\x18\x07 \x01(\x03R\x0bmaxRestarts\x12!\n\x0cnum_restarts\x18\x08 \x01(\x04R\x0bnumRestarts\x12*\n\x07\x61\x64\x64ress\x18\t \x01(\x0b\x32\x10.ray.rpc.AddressR\x07\x61\x64\x64ress\x12\x35\n\rowner_address\x18\n \x01(\x0b\x32\x10.ray.rpc.AddressR\x0cownerAddress\x12\x1f\n\x0bis_detached\x18\x0b \x01(\x08R\nisDetached\x12\x12\n\x04name\x18\x0c \x01(\tR\x04name\x12\x1c\n\ttimestamp\x18\r \x01(\x01R\ttimestamp\x12.\n\ttask_spec\x18\x0e \x01(\x0b\x32\x11.ray.rpc.TaskSpecR\x08taskSpec\x12\x44\n\x10resource_mapping\x18\x0f \x03(\x0b\x32\x19.ray.rpc.ResourceMapEntryR\x0fresourceMapping\x12\x10\n\x03pid\x18\x10 \x01(\rR\x03pid\x12M\n\x17\x63reation_task_exception\x18\x12 \x01(\x0b\x32\x15.ray.rpc.RayExceptionR\x15\x63reationTaskException\x12#\n\rray_namespace\x18\x13 \x01(\tR\x0crayNamespace\x12\x34\n\x0bruntime_env\x18\x14 \x01(\x0b\x32\x13.ray.rpc.RuntimeEnvR\nruntimeEnv\x12\x1d\n\nstart_time\x18\x15 \x01(\x04R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x16 \x01(\x04R\x07\x65ndTime\x12\x1d\n\nclass_name\x18\x17 \x01(\tR\tclassName\x12\x34\n\x16serialized_runtime_env\x18\x18 \x01(\tR\x14serializedRuntimeEnv\"a\n\nActorState\x12\x18\n\x14\x44\x45PENDENCIES_UNREADY\x10\x00\x12\x14\n\x10PENDING_CREATION\x10\x01\x12\t\n\x05\x41LIVE\x10\x02\x12\x0e\n\nRESTARTING\x10\x03\x12\x08\n\x04\x44\x45\x41\x44\x10\x04\"~\n\x0e\x45rrorTableData\x12\x15\n\x06job_id\x18\x01 \x01(\x0cR\x05jobId\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\x12\x1c\n\ttimestamp\x18\x04 \x01(\x01R\ttimestamp\"\x9d\x01\n\x0cScheduleData\x12L\n\rschedule_plan\x18\x01 \x03(\x0b\x32\'.ray.rpc.ScheduleData.SchedulePlanEntryR\x0cschedulePlan\x1a?\n\x11SchedulePlanEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"\xdc\x02\n\x10ProfileTableData\x12%\n\x0e\x63omponent_type\x18\x01 \x01(\tR\rcomponentType\x12!\n\x0c\x63omponent_id\x18\x02 \x01(\x0cR\x0b\x63omponentId\x12&\n\x0fnode_ip_address\x18\x03 \x01(\tR\rnodeIpAddress\x12M\n\x0eprofile_events\x18\x04 \x03(\x0b\x32&.ray.rpc.ProfileTableData.ProfileEventR\rprofileEvents\x1a\x86\x01\n\x0cProfileEvent\x12\x1d\n\nevent_type\x18\x01 \x01(\tR\teventType\x12\x1d\n\nstart_time\x18\x02 \x01(\x01R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x03 \x01(\x01R\x07\x65ndTime\x12\x1d\n\nextra_data\x18\x04 \x01(\tR\textraData\"@\n\x11ResourceTableData\x12+\n\x11resource_capacity\x18\x01 \x01(\x01R\x10resourceCapacity\"\xda\x01\n\x12\x41vailableResources\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12\x64\n\x13resources_available\x18\x02 \x03(\x0b\x32\x33.ray.rpc.AvailableResources.ResourcesAvailableEntryR\x12resourcesAvailable\x1a\x45\n\x17ResourcesAvailableEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xfb\x03\n\x0bGcsNodeInfo\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12\x30\n\x14node_manager_address\x18\x02 \x01(\tR\x12nodeManagerAddress\x12,\n\x12raylet_socket_name\x18\x03 \x01(\tR\x10rayletSocketName\x12\x37\n\x18object_store_socket_name\x18\x04 \x01(\tR\x15objectStoreSocketName\x12*\n\x11node_manager_port\x18\x05 \x01(\x05R\x0fnodeManagerPort\x12.\n\x13object_manager_port\x18\x06 \x01(\x05R\x11objectManagerPort\x12\x37\n\x05state\x18\x07 \x01(\x0e\x32!.ray.rpc.GcsNodeInfo.GcsNodeStateR\x05state\x12\x32\n\x15node_manager_hostname\x18\x08 \x01(\tR\x13nodeManagerHostname\x12.\n\x13metrics_export_port\x18\t \x01(\x05R\x11metricsExportPort\x12\x1c\n\ttimestamp\x18\n \x01(\x03R\ttimestamp\"#\n\x0cGcsNodeState\x12\t\n\x05\x41LIVE\x10\x00\x12\x08\n\x04\x44\x45\x41\x44\x10\x01\"-\n\x12HeartbeatTableData\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\"\x8b\x01\n\rTaskLeaseData\x12\x17\n\x07task_id\x18\x01 \x01(\x0cR\x06taskId\x12&\n\x0fnode_manager_id\x18\x02 \x01(\x0cR\rnodeManagerId\x12\x1f\n\x0b\x61\x63quired_at\x18\x03 \x01(\x04R\nacquiredAt\x12\x18\n\x07timeout\x18\x04 \x01(\x04R\x07timeout\"\xa2\x04\n\tJobConfig\x12@\n\nworker_env\x18\x01 \x03(\x0b\x32!.ray.rpc.JobConfig.WorkerEnvEntryR\tworkerEnv\x12>\n\x1cnum_java_workers_per_process\x18\x02 \x01(\rR\x18numJavaWorkersPerProcess\x12\x1f\n\x0bjvm_options\x18\x03 \x03(\tR\njvmOptions\x12(\n\x10\x63ode_search_path\x18\x04 \x03(\tR\x0e\x63odeSearchPath\x12\x34\n\x0bruntime_env\x18\x05 \x01(\x0b\x32\x13.ray.rpc.RuntimeEnvR\nruntimeEnv\x12#\n\rray_namespace\x18\x06 \x01(\tR\x0crayNamespace\x12\x34\n\x16serialized_runtime_env\x18\x07 \x01(\tR\x14serializedRuntimeEnv\x12<\n\x08metadata\x18\x08 \x03(\x0b\x32 .ray.rpc.JobConfig.MetadataEntryR\x08metadata\x1a<\n\x0eWorkerEnvEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8d\x02\n\x0cJobTableData\x12\x15\n\x06job_id\x18\x01 \x01(\x0cR\x05jobId\x12\x17\n\x07is_dead\x18\x02 \x01(\x08R\x06isDead\x12\x1c\n\ttimestamp\x18\x03 \x01(\x03R\ttimestamp\x12*\n\x11\x64river_ip_address\x18\x04 \x01(\tR\x0f\x64riverIpAddress\x12\x1d\n\ndriver_pid\x18\x05 \x01(\x03R\tdriverPid\x12*\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x12.ray.rpc.JobConfigR\x06\x63onfig\x12\x1d\n\nstart_time\x18\x07 \x01(\x04R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x08 \x01(\x04R\x07\x65ndTime\"\xc8\x03\n\x0fWorkerTableData\x12\x19\n\x08is_alive\x18\x01 \x01(\x08R\x07isAlive\x12\x37\n\x0eworker_address\x18\x02 \x01(\x0b\x32\x10.ray.rpc.AddressR\rworkerAddress\x12\x1c\n\ttimestamp\x18\x03 \x01(\x03R\ttimestamp\x12\x34\n\texit_type\x18\x04 \x01(\x0e\x32\x17.ray.rpc.WorkerExitTypeR\x08\x65xitType\x12\x34\n\x0bworker_type\x18\x05 \x01(\x0e\x32\x13.ray.rpc.WorkerTypeR\nworkerType\x12I\n\x0bworker_info\x18\x06 \x03(\x0b\x32(.ray.rpc.WorkerTableData.WorkerInfoEntryR\nworkerInfo\x12M\n\x17\x63reation_task_exception\x18\x12 \x01(\x0b\x32\x15.ray.rpc.RayExceptionR\x15\x63reationTaskException\x1a=\n\x0fWorkerInfoEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"K\n\x0fWorkerDeltaData\x12\x1b\n\traylet_id\x18\x01 \x01(\x0cR\x08rayletId\x12\x1b\n\tworker_id\x18\x02 \x01(\x0cR\x08workerId\"\x9a\x01\n\x0bResourceMap\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32\x1f.ray.rpc.ResourceMap.ItemsEntryR\x05items\x1aT\n\nItemsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.ray.rpc.ResourceTableDataR\x05value:\x02\x38\x01\"&\n\x0cStoredConfig\x12\x16\n\x06\x63onfig\x18\x01 \x01(\tR\x06\x63onfig\"\xc6\x01\n\x12ObjectLocationInfo\x12\x1b\n\tobject_id\x18\x01 \x01(\x0cR\x08objectId\x12\x36\n\tlocations\x18\x02 \x03(\x0b\x32\x18.ray.rpc.ObjectTableDataR\tlocations\x12\x1f\n\x0bspilled_url\x18\x03 \x01(\tR\nspilledUrl\x12&\n\x0fspilled_node_id\x18\x04 \x01(\x0cR\rspilledNodeId\x12\x12\n\x04size\x18\x05 \x01(\x04R\x04size\"\xa3\x01\n\x14ObjectLocationChange\x12\x15\n\x06is_add\x18\x01 \x01(\x08R\x05isAdd\x12\x17\n\x07node_id\x18\x02 \x01(\x0cR\x06nodeId\x12\x1f\n\x0bspilled_url\x18\x03 \x01(\tR\nspilledUrl\x12&\n\x0fspilled_node_id\x18\x04 \x01(\x0cR\rspilledNodeId\x12\x12\n\x04size\x18\x05 \x01(\x04R\x04size\"\xff\x01\n\x12NodeResourceChange\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12^\n\x11updated_resources\x18\x02 \x03(\x0b\x32\x31.ray.rpc.NodeResourceChange.UpdatedResourcesEntryR\x10updatedResources\x12+\n\x11\x64\x65leted_resources\x18\x03 \x03(\tR\x10\x64\x65letedResources\x1a\x43\n\x15UpdatedResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"3\n\rPubSubMessage\x12\x0e\n\x02id\x18\x01 \x01(\x0cR\x02id\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\"\x90\x01\n\x0eResourceUpdate\x12\x35\n\x06\x63hange\x18\x01 \x01(\x0b\x32\x1b.ray.rpc.NodeResourceChangeH\x00R\x06\x63hange\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.ray.rpc.ResourcesDataH\x00R\x04\x64\x61taB\x19\n\x17resource_change_or_data\"b\n\x1aResourceUsageBroadcastData\x12\x15\n\x06seq_no\x18\x01 \x01(\x03R\x05seqNo\x12-\n\x05\x62\x61tch\x18\x02 \x03(\x0b\x32\x17.ray.rpc.ResourceUpdateR\x05\x62\x61tch\"\xa7\x02\n\x0eResourceDemand\x12\x38\n\x05shape\x18\x01 \x03(\x0b\x32\".ray.rpc.ResourceDemand.ShapeEntryR\x05shape\x12\x39\n\x19num_ready_requests_queued\x18\x02 \x01(\x04R\x16numReadyRequestsQueued\x12\x43\n\x1enum_infeasible_requests_queued\x18\x03 \x01(\x04R\x1bnumInfeasibleRequestsQueued\x12!\n\x0c\x62\x61\x63klog_size\x18\x04 \x01(\x03R\x0b\x62\x61\x63klogSize\x1a\x38\n\nShapeEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"R\n\x0cResourceLoad\x12\x42\n\x10resource_demands\x18\x01 \x03(\x0b\x32\x17.ray.rpc.ResourceDemandR\x0fresourceDemands\"\x84\x08\n\rResourcesData\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12_\n\x13resources_available\x18\x02 \x03(\x0b\x32..ray.rpc.ResourcesData.ResourcesAvailableEntryR\x12resourcesAvailable\x12>\n\x1bresources_available_changed\x18\x03 \x01(\x08R\x19resourcesAvailableChanged\x12S\n\x0fresources_total\x18\x04 \x03(\x0b\x32*.ray.rpc.ResourcesData.ResourcesTotalEntryR\x0eresourcesTotal\x12M\n\rresource_load\x18\x05 \x03(\x0b\x32(.ray.rpc.ResourcesData.ResourceLoadEntryR\x0cresourceLoad\x12\x32\n\x15resource_load_changed\x18\x06 \x01(\x08R\x13resourceLoadChanged\x12J\n\x16resource_load_by_shape\x18\x07 \x01(\x0b\x32\x15.ray.rpc.ResourceLoadR\x13resourceLoadByShape\x12(\n\x10should_global_gc\x18\x08 \x01(\x08R\x0eshouldGlobalGc\x12\x30\n\x14node_manager_address\x18\t \x01(\tR\x12nodeManagerAddress\x12\x63\n\x15resources_normal_task\x18\n \x03(\x0b\x32/.ray.rpc.ResourcesData.ResourcesNormalTaskEntryR\x13resourcesNormalTask\x12\x41\n\x1dresources_normal_task_changed\x18\x0b \x01(\x08R\x1aresourcesNormalTaskChanged\x1a\x45\n\x17ResourcesAvailableEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a\x41\n\x13ResourcesTotalEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a?\n\x11ResourceLoadEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a\x46\n\x18ResourcesNormalTaskEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xe1\x01\n\x16ResourceUsageBatchData\x12,\n\x05\x62\x61tch\x18\x01 \x03(\x0b\x32\x16.ray.rpc.ResourcesDataR\x05\x62\x61tch\x12J\n\x16resource_load_by_shape\x18\x02 \x01(\x0b\x32\x15.ray.rpc.ResourceLoadR\x13resourceLoadByShape\x12M\n\x14placement_group_load\x18\x03 \x01(\x0b\x32\x1b.ray.rpc.PlacementGroupLoadR\x12placementGroupLoad\"h\n\x12PlacementGroupLoad\x12R\n\x14placement_group_data\x18\x01 \x03(\x0b\x32 .ray.rpc.PlacementGroupTableDataR\x12placementGroupData\"\xc8\x04\n\x17PlacementGroupTableData\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12)\n\x07\x62undles\x18\x03 \x03(\x0b\x32\x0f.ray.rpc.BundleR\x07\x62undles\x12\x36\n\x08strategy\x18\x04 \x01(\x0e\x32\x1a.ray.rpc.PlacementStrategyR\x08strategy\x12J\n\x05state\x18\x05 \x01(\x0e\x32\x34.ray.rpc.PlacementGroupTableData.PlacementGroupStateR\x05state\x12$\n\x0e\x63reator_job_id\x18\x06 \x01(\x0cR\x0c\x63reatorJobId\x12(\n\x10\x63reator_actor_id\x18\x07 \x01(\x0cR\x0e\x63reatorActorId\x12(\n\x10\x63reator_job_dead\x18\x08 \x01(\x08R\x0e\x63reatorJobDead\x12,\n\x12\x63reator_actor_dead\x18\t \x01(\x08R\x10\x63reatorActorDead\x12\x1f\n\x0bis_detached\x18\n \x01(\x08R\nisDetached\x12#\n\rray_namespace\x18\x0b \x01(\tR\x0crayNamespace\"N\n\x13PlacementGroupState\x12\x0b\n\x07PENDING\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x12\x10\n\x0cRESCHEDULING\x10\x03*\xf9\x02\n\x0bTablePrefix\x12\x14\n\x10TABLE_PREFIX_MIN\x10\x00\x12\n\n\x06UNUSED\x10\x01\x12\x08\n\x04TASK\x10\x02\x12\x0f\n\x0bRAYLET_TASK\x10\x03\x12\x08\n\x04NODE\x10\x04\x12\n\n\x06OBJECT\x10\x05\x12\t\n\x05\x41\x43TOR\x10\x06\x12\x0c\n\x08\x46UNCTION\x10\x07\x12\x17\n\x13TASK_RECONSTRUCTION\x10\x08\x12\r\n\tHEARTBEAT\x10\t\x12\x18\n\x14RESOURCE_USAGE_BATCH\x10\n\x12\x07\n\x03JOB\x10\x0b\x12\x0b\n\x07PROFILE\x10\x0c\x12\x0e\n\nTASK_LEASE\x10\r\x12\x11\n\rNODE_RESOURCE\x10\x10\x12\x10\n\x0c\x44IRECT_ACTOR\x10\x11\x12\x0b\n\x07WORKERS\x10\x12\x12\x13\n\x0fINTERNAL_CONFIG\x10\x1d\x12\x14\n\x10TABLE_PREFIX_MAX\x10\x14\x12\x1c\n\x18PLACEMENT_GROUP_SCHEDULE\x10\x15\x12\x13\n\x0fPLACEMENT_GROUP\x10\x16\x12\x06\n\x02KV\x10\x17*\xd4\x02\n\x0bTablePubsub\x12\x14\n\x10TABLE_PUBSUB_MIN\x10\x00\x12\x0e\n\nNO_PUBLISH\x10\x01\x12\x0f\n\x0bTASK_PUBSUB\x10\x02\x12\x16\n\x12RAYLET_TASK_PUBSUB\x10\x03\x12\x0f\n\x0bNODE_PUBSUB\x10\x04\x12\x11\n\rOBJECT_PUBSUB\x10\x05\x12\x10\n\x0c\x41\x43TOR_PUBSUB\x10\x06\x12\x14\n\x10HEARTBEAT_PUBSUB\x10\x07\x12\x1f\n\x1bRESOURCE_USAGE_BATCH_PUBSUB\x10\x08\x12\x15\n\x11TASK_LEASE_PUBSUB\x10\t\x12\x0e\n\nJOB_PUBSUB\x10\n\x12\x18\n\x14NODE_RESOURCE_PUBSUB\x10\x0b\x12\x17\n\x13\x44IRECT_ACTOR_PUBSUB\x10\x0c\x12\x19\n\x15WORKER_FAILURE_PUBSUB\x10\r\x12\x14\n\x10TABLE_PUBSUB_MAX\x10\x0e*.\n\rGcsChangeMode\x12\x11\n\rAPPEND_OR_ADD\x10\x00\x12\n\n\x06REMOVE\x10\x01\x42\x1a\n\x18io.ray.runtime.generatedb\x06proto3'
  ,
  dependencies=[src_dot_ray_dot_protobuf_dot_common__pb2.DESCRIPTOR,])

_TABLEPREFIX = _descriptor.EnumDescriptor(
  name='TablePrefix',
  full_name='ray.rpc.TablePrefix',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TABLE_PREFIX_MIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNUSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TASK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAYLET_TASK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NODE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTOR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FUNCTION', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TASK_RECONSTRUCTION', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEARTBEAT', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_USAGE_BATCH', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOB', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROFILE', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TASK_LEASE', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NODE_RESOURCE', index=14, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECT_ACTOR', index=15, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WORKERS', index=16, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_CONFIG', index=17, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TABLE_PREFIX_MAX', index=18, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT_GROUP_SCHEDULE', index=19, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT_GROUP', index=20, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KV', index=21, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7882,
  serialized_end=8259,
)
_sym_db.RegisterEnumDescriptor(_TABLEPREFIX)

TablePrefix = enum_type_wrapper.EnumTypeWrapper(_TABLEPREFIX)
_TABLEPUBSUB = _descriptor.EnumDescriptor(
  name='TablePubsub',
  full_name='ray.rpc.TablePubsub',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TABLE_PUBSUB_MIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_PUBLISH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TASK_PUBSUB', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAYLET_TASK_PUBSUB', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NODE_PUBSUB', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_PUBSUB', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTOR_PUBSUB', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEARTBEAT_PUBSUB', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_USAGE_BATCH_PUBSUB', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TASK_LEASE_PUBSUB', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOB_PUBSUB', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NODE_RESOURCE_PUBSUB', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECT_ACTOR_PUBSUB', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WORKER_FAILURE_PUBSUB', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TABLE_PUBSUB_MAX', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8262,
  serialized_end=8602,
)
_sym_db.RegisterEnumDescriptor(_TABLEPUBSUB)

TablePubsub = enum_type_wrapper.EnumTypeWrapper(_TABLEPUBSUB)
_GCSCHANGEMODE = _descriptor.EnumDescriptor(
  name='GcsChangeMode',
  full_name='ray.rpc.GcsChangeMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='APPEND_OR_ADD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REMOVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8604,
  serialized_end=8650,
)
_sym_db.RegisterEnumDescriptor(_GCSCHANGEMODE)

GcsChangeMode = enum_type_wrapper.EnumTypeWrapper(_GCSCHANGEMODE)
TABLE_PREFIX_MIN = 0
UNUSED = 1
TASK = 2
RAYLET_TASK = 3
NODE = 4
OBJECT = 5
ACTOR = 6
FUNCTION = 7
TASK_RECONSTRUCTION = 8
HEARTBEAT = 9
RESOURCE_USAGE_BATCH = 10
JOB = 11
PROFILE = 12
TASK_LEASE = 13
NODE_RESOURCE = 16
DIRECT_ACTOR = 17
WORKERS = 18
INTERNAL_CONFIG = 29
TABLE_PREFIX_MAX = 20
PLACEMENT_GROUP_SCHEDULE = 21
PLACEMENT_GROUP = 22
KV = 23
TABLE_PUBSUB_MIN = 0
NO_PUBLISH = 1
TASK_PUBSUB = 2
RAYLET_TASK_PUBSUB = 3
NODE_PUBSUB = 4
OBJECT_PUBSUB = 5
ACTOR_PUBSUB = 6
HEARTBEAT_PUBSUB = 7
RESOURCE_USAGE_BATCH_PUBSUB = 8
TASK_LEASE_PUBSUB = 9
JOB_PUBSUB = 10
NODE_RESOURCE_PUBSUB = 11
DIRECT_ACTOR_PUBSUB = 12
WORKER_FAILURE_PUBSUB = 13
TABLE_PUBSUB_MAX = 14
APPEND_OR_ADD = 0
REMOVE = 1


_ACTORTABLEDATA_ACTORSTATE = _descriptor.EnumDescriptor(
  name='ActorState',
  full_name='ray.rpc.ActorTableData.ActorState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEPENDENCIES_UNREADY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING_CREATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESTARTING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEAD', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1344,
  serialized_end=1441,
)
_sym_db.RegisterEnumDescriptor(_ACTORTABLEDATA_ACTORSTATE)

_GCSNODEINFO_GCSNODESTATE = _descriptor.EnumDescriptor(
  name='GcsNodeState',
  full_name='ray.rpc.GcsNodeInfo.GcsNodeState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEAD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2842,
  serialized_end=2877,
)
_sym_db.RegisterEnumDescriptor(_GCSNODEINFO_GCSNODESTATE)

_PLACEMENTGROUPTABLEDATA_PLACEMENTGROUPSTATE = _descriptor.EnumDescriptor(
  name='PlacementGroupState',
  full_name='ray.rpc.PlacementGroupTableData.PlacementGroupState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REMOVED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESCHEDULING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7801,
  serialized_end=7879,
)
_sym_db.RegisterEnumDescriptor(_PLACEMENTGROUPTABLEDATA_PLACEMENTGROUPSTATE)


_GCSENTRY = _descriptor.Descriptor(
  name='GcsEntry',
  full_name='ray.rpc.GcsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_mode', full_name='ray.rpc.GcsEntry.change_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='changeMode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='ray.rpc.GcsEntry.id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entries', full_name='ray.rpc.GcsEntry.entries', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=179,
)


_OBJECTTABLEDATA = _descriptor.Descriptor(
  name='ObjectTableData',
  full_name='ray.rpc.ObjectTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manager', full_name='ray.rpc.ObjectTableData.manager', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='manager', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=224,
)


_TASKRECONSTRUCTIONDATA = _descriptor.Descriptor(
  name='TaskReconstructionData',
  full_name='ray.rpc.TaskReconstructionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ray.rpc.TaskReconstructionData.task_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_reconstructions', full_name='ray.rpc.TaskReconstructionData.num_reconstructions', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numReconstructions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_manager_id', full_name='ray.rpc.TaskReconstructionData.node_manager_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeManagerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=365,
)


_TASKTABLEDATA = _descriptor.Descriptor(
  name='TaskTableData',
  full_name='ray.rpc.TaskTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task', full_name='ray.rpc.TaskTableData.task', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='task', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=417,
)


_ACTORTABLEDATA = _descriptor.Descriptor(
  name='ActorTableData',
  full_name='ray.rpc.ActorTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='ray.rpc.ActorTableData.actor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='ray.rpc.ActorTableData.parent_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parentId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_creation_dummy_object_id', full_name='ray.rpc.ActorTableData.actor_creation_dummy_object_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorCreationDummyObjectId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.ActorTableData.job_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='ray.rpc.ActorTableData.state', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='state', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_restarts', full_name='ray.rpc.ActorTableData.max_restarts', index=5,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxRestarts', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_restarts', full_name='ray.rpc.ActorTableData.num_restarts', index=6,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numRestarts', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='ray.rpc.ActorTableData.address', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='address', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_address', full_name='ray.rpc.ActorTableData.owner_address', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ownerAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_detached', full_name='ray.rpc.ActorTableData.is_detached', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isDetached', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.ActorTableData.name', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ray.rpc.ActorTableData.timestamp', index=11,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_spec', full_name='ray.rpc.ActorTableData.task_spec', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskSpec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_mapping', full_name='ray.rpc.ActorTableData.resource_mapping', index=13,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceMapping', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pid', full_name='ray.rpc.ActorTableData.pid', index=14,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pid', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_task_exception', full_name='ray.rpc.ActorTableData.creation_task_exception', index=15,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creationTaskException', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ray_namespace', full_name='ray.rpc.ActorTableData.ray_namespace', index=16,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayNamespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_env', full_name='ray.rpc.ActorTableData.runtime_env', index=17,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='runtimeEnv', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='ray.rpc.ActorTableData.start_time', index=18,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='ray.rpc.ActorTableData.end_time', index=19,
      number=22, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='endTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='ray.rpc.ActorTableData.class_name', index=20,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='className', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serialized_runtime_env', full_name='ray.rpc.ActorTableData.serialized_runtime_env', index=21,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='serializedRuntimeEnv', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ACTORTABLEDATA_ACTORSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=1441,
)


_ERRORTABLEDATA = _descriptor.Descriptor(
  name='ErrorTableData',
  full_name='ray.rpc.ErrorTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.ErrorTableData.job_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='ray.rpc.ErrorTableData.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='ray.rpc.ErrorTableData.error_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='errorMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ray.rpc.ErrorTableData.timestamp', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1569,
)


_SCHEDULEDATA_SCHEDULEPLANENTRY = _descriptor.Descriptor(
  name='SchedulePlanEntry',
  full_name='ray.rpc.ScheduleData.SchedulePlanEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ScheduleData.SchedulePlanEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ScheduleData.SchedulePlanEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1666,
  serialized_end=1729,
)

_SCHEDULEDATA = _descriptor.Descriptor(
  name='ScheduleData',
  full_name='ray.rpc.ScheduleData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule_plan', full_name='ray.rpc.ScheduleData.schedule_plan', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schedulePlan', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCHEDULEDATA_SCHEDULEPLANENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1572,
  serialized_end=1729,
)


_PROFILETABLEDATA_PROFILEEVENT = _descriptor.Descriptor(
  name='ProfileEvent',
  full_name='ray.rpc.ProfileTableData.ProfileEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_type', full_name='ray.rpc.ProfileTableData.ProfileEvent.event_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='ray.rpc.ProfileTableData.ProfileEvent.start_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='ray.rpc.ProfileTableData.ProfileEvent.end_time', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='endTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_data', full_name='ray.rpc.ProfileTableData.ProfileEvent.extra_data', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='extraData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1946,
  serialized_end=2080,
)

_PROFILETABLEDATA = _descriptor.Descriptor(
  name='ProfileTableData',
  full_name='ray.rpc.ProfileTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='component_type', full_name='ray.rpc.ProfileTableData.component_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='componentType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='component_id', full_name='ray.rpc.ProfileTableData.component_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='componentId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_ip_address', full_name='ray.rpc.ProfileTableData.node_ip_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeIpAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_events', full_name='ray.rpc.ProfileTableData.profile_events', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='profileEvents', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PROFILETABLEDATA_PROFILEEVENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1732,
  serialized_end=2080,
)


_RESOURCETABLEDATA = _descriptor.Descriptor(
  name='ResourceTableData',
  full_name='ray.rpc.ResourceTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_capacity', full_name='ray.rpc.ResourceTableData.resource_capacity', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceCapacity', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2082,
  serialized_end=2146,
)


_AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY = _descriptor.Descriptor(
  name='ResourcesAvailableEntry',
  full_name='ray.rpc.AvailableResources.ResourcesAvailableEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.AvailableResources.ResourcesAvailableEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.AvailableResources.ResourcesAvailableEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2298,
  serialized_end=2367,
)

_AVAILABLERESOURCES = _descriptor.Descriptor(
  name='AvailableResources',
  full_name='ray.rpc.AvailableResources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.AvailableResources.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_available', full_name='ray.rpc.AvailableResources.resources_available', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesAvailable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2149,
  serialized_end=2367,
)


_GCSNODEINFO = _descriptor.Descriptor(
  name='GcsNodeInfo',
  full_name='ray.rpc.GcsNodeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.GcsNodeInfo.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_manager_address', full_name='ray.rpc.GcsNodeInfo.node_manager_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeManagerAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raylet_socket_name', full_name='ray.rpc.GcsNodeInfo.raylet_socket_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayletSocketName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_store_socket_name', full_name='ray.rpc.GcsNodeInfo.object_store_socket_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectStoreSocketName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_manager_port', full_name='ray.rpc.GcsNodeInfo.node_manager_port', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeManagerPort', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_manager_port', full_name='ray.rpc.GcsNodeInfo.object_manager_port', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectManagerPort', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='ray.rpc.GcsNodeInfo.state', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='state', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_manager_hostname', full_name='ray.rpc.GcsNodeInfo.node_manager_hostname', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeManagerHostname', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics_export_port', full_name='ray.rpc.GcsNodeInfo.metrics_export_port', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metricsExportPort', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ray.rpc.GcsNodeInfo.timestamp', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GCSNODEINFO_GCSNODESTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2370,
  serialized_end=2877,
)


_HEARTBEATTABLEDATA = _descriptor.Descriptor(
  name='HeartbeatTableData',
  full_name='ray.rpc.HeartbeatTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.HeartbeatTableData.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2879,
  serialized_end=2924,
)


_TASKLEASEDATA = _descriptor.Descriptor(
  name='TaskLeaseData',
  full_name='ray.rpc.TaskLeaseData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ray.rpc.TaskLeaseData.task_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_manager_id', full_name='ray.rpc.TaskLeaseData.node_manager_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeManagerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acquired_at', full_name='ray.rpc.TaskLeaseData.acquired_at', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='acquiredAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='ray.rpc.TaskLeaseData.timeout', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeout', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2927,
  serialized_end=3066,
)


_JOBCONFIG_WORKERENVENTRY = _descriptor.Descriptor(
  name='WorkerEnvEntry',
  full_name='ray.rpc.JobConfig.WorkerEnvEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.JobConfig.WorkerEnvEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.JobConfig.WorkerEnvEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3494,
  serialized_end=3554,
)

_JOBCONFIG_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='ray.rpc.JobConfig.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.JobConfig.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.JobConfig.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3556,
  serialized_end=3615,
)

_JOBCONFIG = _descriptor.Descriptor(
  name='JobConfig',
  full_name='ray.rpc.JobConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_env', full_name='ray.rpc.JobConfig.worker_env', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerEnv', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_java_workers_per_process', full_name='ray.rpc.JobConfig.num_java_workers_per_process', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numJavaWorkersPerProcess', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jvm_options', full_name='ray.rpc.JobConfig.jvm_options', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jvmOptions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_search_path', full_name='ray.rpc.JobConfig.code_search_path', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='codeSearchPath', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_env', full_name='ray.rpc.JobConfig.runtime_env', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='runtimeEnv', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ray_namespace', full_name='ray.rpc.JobConfig.ray_namespace', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayNamespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serialized_runtime_env', full_name='ray.rpc.JobConfig.serialized_runtime_env', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='serializedRuntimeEnv', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='ray.rpc.JobConfig.metadata', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_JOBCONFIG_WORKERENVENTRY, _JOBCONFIG_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3069,
  serialized_end=3615,
)


_JOBTABLEDATA = _descriptor.Descriptor(
  name='JobTableData',
  full_name='ray.rpc.JobTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.JobTableData.job_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_dead', full_name='ray.rpc.JobTableData.is_dead', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isDead', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ray.rpc.JobTableData.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_ip_address', full_name='ray.rpc.JobTableData.driver_ip_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='driverIpAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_pid', full_name='ray.rpc.JobTableData.driver_pid', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='driverPid', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='ray.rpc.JobTableData.config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='config', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='ray.rpc.JobTableData.start_time', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='ray.rpc.JobTableData.end_time', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='endTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3618,
  serialized_end=3887,
)


_WORKERTABLEDATA_WORKERINFOENTRY = _descriptor.Descriptor(
  name='WorkerInfoEntry',
  full_name='ray.rpc.WorkerTableData.WorkerInfoEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.WorkerTableData.WorkerInfoEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.WorkerTableData.WorkerInfoEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4285,
  serialized_end=4346,
)

_WORKERTABLEDATA = _descriptor.Descriptor(
  name='WorkerTableData',
  full_name='ray.rpc.WorkerTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_alive', full_name='ray.rpc.WorkerTableData.is_alive', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isAlive', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_address', full_name='ray.rpc.WorkerTableData.worker_address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ray.rpc.WorkerTableData.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_type', full_name='ray.rpc.WorkerTableData.exit_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='exitType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_type', full_name='ray.rpc.WorkerTableData.worker_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_info', full_name='ray.rpc.WorkerTableData.worker_info', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_task_exception', full_name='ray.rpc.WorkerTableData.creation_task_exception', index=6,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creationTaskException', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WORKERTABLEDATA_WORKERINFOENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3890,
  serialized_end=4346,
)


_WORKERDELTADATA = _descriptor.Descriptor(
  name='WorkerDeltaData',
  full_name='ray.rpc.WorkerDeltaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raylet_id', full_name='ray.rpc.WorkerDeltaData.raylet_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayletId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_id', full_name='ray.rpc.WorkerDeltaData.worker_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4348,
  serialized_end=4423,
)


_RESOURCEMAP_ITEMSENTRY = _descriptor.Descriptor(
  name='ItemsEntry',
  full_name='ray.rpc.ResourceMap.ItemsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ResourceMap.ItemsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ResourceMap.ItemsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4496,
  serialized_end=4580,
)

_RESOURCEMAP = _descriptor.Descriptor(
  name='ResourceMap',
  full_name='ray.rpc.ResourceMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='ray.rpc.ResourceMap.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='items', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEMAP_ITEMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4426,
  serialized_end=4580,
)


_STOREDCONFIG = _descriptor.Descriptor(
  name='StoredConfig',
  full_name='ray.rpc.StoredConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='ray.rpc.StoredConfig.config', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='config', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4582,
  serialized_end=4620,
)


_OBJECTLOCATIONINFO = _descriptor.Descriptor(
  name='ObjectLocationInfo',
  full_name='ray.rpc.ObjectLocationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_id', full_name='ray.rpc.ObjectLocationInfo.object_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locations', full_name='ray.rpc.ObjectLocationInfo.locations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='locations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spilled_url', full_name='ray.rpc.ObjectLocationInfo.spilled_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spilledUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spilled_node_id', full_name='ray.rpc.ObjectLocationInfo.spilled_node_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spilledNodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='ray.rpc.ObjectLocationInfo.size', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='size', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4623,
  serialized_end=4821,
)


_OBJECTLOCATIONCHANGE = _descriptor.Descriptor(
  name='ObjectLocationChange',
  full_name='ray.rpc.ObjectLocationChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_add', full_name='ray.rpc.ObjectLocationChange.is_add', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isAdd', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.ObjectLocationChange.node_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spilled_url', full_name='ray.rpc.ObjectLocationChange.spilled_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spilledUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spilled_node_id', full_name='ray.rpc.ObjectLocationChange.spilled_node_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spilledNodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='ray.rpc.ObjectLocationChange.size', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='size', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4824,
  serialized_end=4987,
)


_NODERESOURCECHANGE_UPDATEDRESOURCESENTRY = _descriptor.Descriptor(
  name='UpdatedResourcesEntry',
  full_name='ray.rpc.NodeResourceChange.UpdatedResourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.NodeResourceChange.UpdatedResourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.NodeResourceChange.UpdatedResourcesEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5178,
  serialized_end=5245,
)

_NODERESOURCECHANGE = _descriptor.Descriptor(
  name='NodeResourceChange',
  full_name='ray.rpc.NodeResourceChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.NodeResourceChange.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_resources', full_name='ray.rpc.NodeResourceChange.updated_resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='updatedResources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_resources', full_name='ray.rpc.NodeResourceChange.deleted_resources', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deletedResources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODERESOURCECHANGE_UPDATEDRESOURCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4990,
  serialized_end=5245,
)


_PUBSUBMESSAGE = _descriptor.Descriptor(
  name='PubSubMessage',
  full_name='ray.rpc.PubSubMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ray.rpc.PubSubMessage.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ray.rpc.PubSubMessage.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5247,
  serialized_end=5298,
)


_RESOURCEUPDATE = _descriptor.Descriptor(
  name='ResourceUpdate',
  full_name='ray.rpc.ResourceUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change', full_name='ray.rpc.ResourceUpdate.change', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='change', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ray.rpc.ResourceUpdate.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='resource_change_or_data', full_name='ray.rpc.ResourceUpdate.resource_change_or_data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5301,
  serialized_end=5445,
)


_RESOURCEUSAGEBROADCASTDATA = _descriptor.Descriptor(
  name='ResourceUsageBroadcastData',
  full_name='ray.rpc.ResourceUsageBroadcastData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq_no', full_name='ray.rpc.ResourceUsageBroadcastData.seq_no', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='seqNo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch', full_name='ray.rpc.ResourceUsageBroadcastData.batch', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batch', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5447,
  serialized_end=5545,
)


_RESOURCEDEMAND_SHAPEENTRY = _descriptor.Descriptor(
  name='ShapeEntry',
  full_name='ray.rpc.ResourceDemand.ShapeEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ResourceDemand.ShapeEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ResourceDemand.ShapeEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5787,
  serialized_end=5843,
)

_RESOURCEDEMAND = _descriptor.Descriptor(
  name='ResourceDemand',
  full_name='ray.rpc.ResourceDemand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='ray.rpc.ResourceDemand.shape', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='shape', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_ready_requests_queued', full_name='ray.rpc.ResourceDemand.num_ready_requests_queued', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numReadyRequestsQueued', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_infeasible_requests_queued', full_name='ray.rpc.ResourceDemand.num_infeasible_requests_queued', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numInfeasibleRequestsQueued', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backlog_size', full_name='ray.rpc.ResourceDemand.backlog_size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='backlogSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEDEMAND_SHAPEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5548,
  serialized_end=5843,
)


_RESOURCELOAD = _descriptor.Descriptor(
  name='ResourceLoad',
  full_name='ray.rpc.ResourceLoad',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_demands', full_name='ray.rpc.ResourceLoad.resource_demands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceDemands', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5845,
  serialized_end=5927,
)


_RESOURCESDATA_RESOURCESAVAILABLEENTRY = _descriptor.Descriptor(
  name='ResourcesAvailableEntry',
  full_name='ray.rpc.ResourcesData.ResourcesAvailableEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ResourcesData.ResourcesAvailableEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ResourcesData.ResourcesAvailableEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2298,
  serialized_end=2367,
)

_RESOURCESDATA_RESOURCESTOTALENTRY = _descriptor.Descriptor(
  name='ResourcesTotalEntry',
  full_name='ray.rpc.ResourcesData.ResourcesTotalEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ResourcesData.ResourcesTotalEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ResourcesData.ResourcesTotalEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6756,
  serialized_end=6821,
)

_RESOURCESDATA_RESOURCELOADENTRY = _descriptor.Descriptor(
  name='ResourceLoadEntry',
  full_name='ray.rpc.ResourcesData.ResourceLoadEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ResourcesData.ResourceLoadEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ResourcesData.ResourceLoadEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6823,
  serialized_end=6886,
)

_RESOURCESDATA_RESOURCESNORMALTASKENTRY = _descriptor.Descriptor(
  name='ResourcesNormalTaskEntry',
  full_name='ray.rpc.ResourcesData.ResourcesNormalTaskEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ResourcesData.ResourcesNormalTaskEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ResourcesData.ResourcesNormalTaskEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6888,
  serialized_end=6958,
)

_RESOURCESDATA = _descriptor.Descriptor(
  name='ResourcesData',
  full_name='ray.rpc.ResourcesData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.ResourcesData.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_available', full_name='ray.rpc.ResourcesData.resources_available', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesAvailable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_available_changed', full_name='ray.rpc.ResourcesData.resources_available_changed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesAvailableChanged', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_total', full_name='ray.rpc.ResourcesData.resources_total', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesTotal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_load', full_name='ray.rpc.ResourcesData.resource_load', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceLoad', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_load_changed', full_name='ray.rpc.ResourcesData.resource_load_changed', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceLoadChanged', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_load_by_shape', full_name='ray.rpc.ResourcesData.resource_load_by_shape', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceLoadByShape', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='should_global_gc', full_name='ray.rpc.ResourcesData.should_global_gc', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='shouldGlobalGc', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_manager_address', full_name='ray.rpc.ResourcesData.node_manager_address', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeManagerAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_normal_task', full_name='ray.rpc.ResourcesData.resources_normal_task', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesNormalTask', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_normal_task_changed', full_name='ray.rpc.ResourcesData.resources_normal_task_changed', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesNormalTaskChanged', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCESDATA_RESOURCESAVAILABLEENTRY, _RESOURCESDATA_RESOURCESTOTALENTRY, _RESOURCESDATA_RESOURCELOADENTRY, _RESOURCESDATA_RESOURCESNORMALTASKENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5930,
  serialized_end=6958,
)


_RESOURCEUSAGEBATCHDATA = _descriptor.Descriptor(
  name='ResourceUsageBatchData',
  full_name='ray.rpc.ResourceUsageBatchData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch', full_name='ray.rpc.ResourceUsageBatchData.batch', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batch', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_load_by_shape', full_name='ray.rpc.ResourceUsageBatchData.resource_load_by_shape', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceLoadByShape', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_group_load', full_name='ray.rpc.ResourceUsageBatchData.placement_group_load', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupLoad', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6961,
  serialized_end=7186,
)


_PLACEMENTGROUPLOAD = _descriptor.Descriptor(
  name='PlacementGroupLoad',
  full_name='ray.rpc.PlacementGroupLoad',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_data', full_name='ray.rpc.PlacementGroupLoad.placement_group_data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7188,
  serialized_end=7292,
)


_PLACEMENTGROUPTABLEDATA = _descriptor.Descriptor(
  name='PlacementGroupTableData',
  full_name='ray.rpc.PlacementGroupTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='ray.rpc.PlacementGroupTableData.placement_group_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.PlacementGroupTableData.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bundles', full_name='ray.rpc.PlacementGroupTableData.bundles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bundles', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy', full_name='ray.rpc.PlacementGroupTableData.strategy', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='strategy', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='ray.rpc.PlacementGroupTableData.state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='state', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_job_id', full_name='ray.rpc.PlacementGroupTableData.creator_job_id', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorJobId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_actor_id', full_name='ray.rpc.PlacementGroupTableData.creator_actor_id', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorActorId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_job_dead', full_name='ray.rpc.PlacementGroupTableData.creator_job_dead', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorJobDead', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_actor_dead', full_name='ray.rpc.PlacementGroupTableData.creator_actor_dead', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorActorDead', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_detached', full_name='ray.rpc.PlacementGroupTableData.is_detached', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isDetached', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ray_namespace', full_name='ray.rpc.PlacementGroupTableData.ray_namespace', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayNamespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLACEMENTGROUPTABLEDATA_PLACEMENTGROUPSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7295,
  serialized_end=7879,
)

_GCSENTRY.fields_by_name['change_mode'].enum_type = _GCSCHANGEMODE
_TASKTABLEDATA.fields_by_name['task'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._TASK
_ACTORTABLEDATA.fields_by_name['state'].enum_type = _ACTORTABLEDATA_ACTORSTATE
_ACTORTABLEDATA.fields_by_name['address'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._ADDRESS
_ACTORTABLEDATA.fields_by_name['owner_address'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._ADDRESS
_ACTORTABLEDATA.fields_by_name['task_spec'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._TASKSPEC
_ACTORTABLEDATA.fields_by_name['resource_mapping'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._RESOURCEMAPENTRY
_ACTORTABLEDATA.fields_by_name['creation_task_exception'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._RAYEXCEPTION
_ACTORTABLEDATA.fields_by_name['runtime_env'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._RUNTIMEENV
_ACTORTABLEDATA_ACTORSTATE.containing_type = _ACTORTABLEDATA
_SCHEDULEDATA_SCHEDULEPLANENTRY.containing_type = _SCHEDULEDATA
_SCHEDULEDATA.fields_by_name['schedule_plan'].message_type = _SCHEDULEDATA_SCHEDULEPLANENTRY
_PROFILETABLEDATA_PROFILEEVENT.containing_type = _PROFILETABLEDATA
_PROFILETABLEDATA.fields_by_name['profile_events'].message_type = _PROFILETABLEDATA_PROFILEEVENT
_AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY.containing_type = _AVAILABLERESOURCES
_AVAILABLERESOURCES.fields_by_name['resources_available'].message_type = _AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY
_GCSNODEINFO.fields_by_name['state'].enum_type = _GCSNODEINFO_GCSNODESTATE
_GCSNODEINFO_GCSNODESTATE.containing_type = _GCSNODEINFO
_JOBCONFIG_WORKERENVENTRY.containing_type = _JOBCONFIG
_JOBCONFIG_METADATAENTRY.containing_type = _JOBCONFIG
_JOBCONFIG.fields_by_name['worker_env'].message_type = _JOBCONFIG_WORKERENVENTRY
_JOBCONFIG.fields_by_name['runtime_env'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._RUNTIMEENV
_JOBCONFIG.fields_by_name['metadata'].message_type = _JOBCONFIG_METADATAENTRY
_JOBTABLEDATA.fields_by_name['config'].message_type = _JOBCONFIG
_WORKERTABLEDATA_WORKERINFOENTRY.containing_type = _WORKERTABLEDATA
_WORKERTABLEDATA.fields_by_name['worker_address'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._ADDRESS
_WORKERTABLEDATA.fields_by_name['exit_type'].enum_type = src_dot_ray_dot_protobuf_dot_common__pb2._WORKEREXITTYPE
_WORKERTABLEDATA.fields_by_name['worker_type'].enum_type = src_dot_ray_dot_protobuf_dot_common__pb2._WORKERTYPE
_WORKERTABLEDATA.fields_by_name['worker_info'].message_type = _WORKERTABLEDATA_WORKERINFOENTRY
_WORKERTABLEDATA.fields_by_name['creation_task_exception'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._RAYEXCEPTION
_RESOURCEMAP_ITEMSENTRY.fields_by_name['value'].message_type = _RESOURCETABLEDATA
_RESOURCEMAP_ITEMSENTRY.containing_type = _RESOURCEMAP
_RESOURCEMAP.fields_by_name['items'].message_type = _RESOURCEMAP_ITEMSENTRY
_OBJECTLOCATIONINFO.fields_by_name['locations'].message_type = _OBJECTTABLEDATA
_NODERESOURCECHANGE_UPDATEDRESOURCESENTRY.containing_type = _NODERESOURCECHANGE
_NODERESOURCECHANGE.fields_by_name['updated_resources'].message_type = _NODERESOURCECHANGE_UPDATEDRESOURCESENTRY
_RESOURCEUPDATE.fields_by_name['change'].message_type = _NODERESOURCECHANGE
_RESOURCEUPDATE.fields_by_name['data'].message_type = _RESOURCESDATA
_RESOURCEUPDATE.oneofs_by_name['resource_change_or_data'].fields.append(
  _RESOURCEUPDATE.fields_by_name['change'])
_RESOURCEUPDATE.fields_by_name['change'].containing_oneof = _RESOURCEUPDATE.oneofs_by_name['resource_change_or_data']
_RESOURCEUPDATE.oneofs_by_name['resource_change_or_data'].fields.append(
  _RESOURCEUPDATE.fields_by_name['data'])
_RESOURCEUPDATE.fields_by_name['data'].containing_oneof = _RESOURCEUPDATE.oneofs_by_name['resource_change_or_data']
_RESOURCEUSAGEBROADCASTDATA.fields_by_name['batch'].message_type = _RESOURCEUPDATE
_RESOURCEDEMAND_SHAPEENTRY.containing_type = _RESOURCEDEMAND
_RESOURCEDEMAND.fields_by_name['shape'].message_type = _RESOURCEDEMAND_SHAPEENTRY
_RESOURCELOAD.fields_by_name['resource_demands'].message_type = _RESOURCEDEMAND
_RESOURCESDATA_RESOURCESAVAILABLEENTRY.containing_type = _RESOURCESDATA
_RESOURCESDATA_RESOURCESTOTALENTRY.containing_type = _RESOURCESDATA
_RESOURCESDATA_RESOURCELOADENTRY.containing_type = _RESOURCESDATA
_RESOURCESDATA_RESOURCESNORMALTASKENTRY.containing_type = _RESOURCESDATA
_RESOURCESDATA.fields_by_name['resources_available'].message_type = _RESOURCESDATA_RESOURCESAVAILABLEENTRY
_RESOURCESDATA.fields_by_name['resources_total'].message_type = _RESOURCESDATA_RESOURCESTOTALENTRY
_RESOURCESDATA.fields_by_name['resource_load'].message_type = _RESOURCESDATA_RESOURCELOADENTRY
_RESOURCESDATA.fields_by_name['resource_load_by_shape'].message_type = _RESOURCELOAD
_RESOURCESDATA.fields_by_name['resources_normal_task'].message_type = _RESOURCESDATA_RESOURCESNORMALTASKENTRY
_RESOURCEUSAGEBATCHDATA.fields_by_name['batch'].message_type = _RESOURCESDATA
_RESOURCEUSAGEBATCHDATA.fields_by_name['resource_load_by_shape'].message_type = _RESOURCELOAD
_RESOURCEUSAGEBATCHDATA.fields_by_name['placement_group_load'].message_type = _PLACEMENTGROUPLOAD
_PLACEMENTGROUPLOAD.fields_by_name['placement_group_data'].message_type = _PLACEMENTGROUPTABLEDATA
_PLACEMENTGROUPTABLEDATA.fields_by_name['bundles'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._BUNDLE
_PLACEMENTGROUPTABLEDATA.fields_by_name['strategy'].enum_type = src_dot_ray_dot_protobuf_dot_common__pb2._PLACEMENTSTRATEGY
_PLACEMENTGROUPTABLEDATA.fields_by_name['state'].enum_type = _PLACEMENTGROUPTABLEDATA_PLACEMENTGROUPSTATE
_PLACEMENTGROUPTABLEDATA_PLACEMENTGROUPSTATE.containing_type = _PLACEMENTGROUPTABLEDATA
DESCRIPTOR.message_types_by_name['GcsEntry'] = _GCSENTRY
DESCRIPTOR.message_types_by_name['ObjectTableData'] = _OBJECTTABLEDATA
DESCRIPTOR.message_types_by_name['TaskReconstructionData'] = _TASKRECONSTRUCTIONDATA
DESCRIPTOR.message_types_by_name['TaskTableData'] = _TASKTABLEDATA
DESCRIPTOR.message_types_by_name['ActorTableData'] = _ACTORTABLEDATA
DESCRIPTOR.message_types_by_name['ErrorTableData'] = _ERRORTABLEDATA
DESCRIPTOR.message_types_by_name['ScheduleData'] = _SCHEDULEDATA
DESCRIPTOR.message_types_by_name['ProfileTableData'] = _PROFILETABLEDATA
DESCRIPTOR.message_types_by_name['ResourceTableData'] = _RESOURCETABLEDATA
DESCRIPTOR.message_types_by_name['AvailableResources'] = _AVAILABLERESOURCES
DESCRIPTOR.message_types_by_name['GcsNodeInfo'] = _GCSNODEINFO
DESCRIPTOR.message_types_by_name['HeartbeatTableData'] = _HEARTBEATTABLEDATA
DESCRIPTOR.message_types_by_name['TaskLeaseData'] = _TASKLEASEDATA
DESCRIPTOR.message_types_by_name['JobConfig'] = _JOBCONFIG
DESCRIPTOR.message_types_by_name['JobTableData'] = _JOBTABLEDATA
DESCRIPTOR.message_types_by_name['WorkerTableData'] = _WORKERTABLEDATA
DESCRIPTOR.message_types_by_name['WorkerDeltaData'] = _WORKERDELTADATA
DESCRIPTOR.message_types_by_name['ResourceMap'] = _RESOURCEMAP
DESCRIPTOR.message_types_by_name['StoredConfig'] = _STOREDCONFIG
DESCRIPTOR.message_types_by_name['ObjectLocationInfo'] = _OBJECTLOCATIONINFO
DESCRIPTOR.message_types_by_name['ObjectLocationChange'] = _OBJECTLOCATIONCHANGE
DESCRIPTOR.message_types_by_name['NodeResourceChange'] = _NODERESOURCECHANGE
DESCRIPTOR.message_types_by_name['PubSubMessage'] = _PUBSUBMESSAGE
DESCRIPTOR.message_types_by_name['ResourceUpdate'] = _RESOURCEUPDATE
DESCRIPTOR.message_types_by_name['ResourceUsageBroadcastData'] = _RESOURCEUSAGEBROADCASTDATA
DESCRIPTOR.message_types_by_name['ResourceDemand'] = _RESOURCEDEMAND
DESCRIPTOR.message_types_by_name['ResourceLoad'] = _RESOURCELOAD
DESCRIPTOR.message_types_by_name['ResourcesData'] = _RESOURCESDATA
DESCRIPTOR.message_types_by_name['ResourceUsageBatchData'] = _RESOURCEUSAGEBATCHDATA
DESCRIPTOR.message_types_by_name['PlacementGroupLoad'] = _PLACEMENTGROUPLOAD
DESCRIPTOR.message_types_by_name['PlacementGroupTableData'] = _PLACEMENTGROUPTABLEDATA
DESCRIPTOR.enum_types_by_name['TablePrefix'] = _TABLEPREFIX
DESCRIPTOR.enum_types_by_name['TablePubsub'] = _TABLEPUBSUB
DESCRIPTOR.enum_types_by_name['GcsChangeMode'] = _GCSCHANGEMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GcsEntry = _reflection.GeneratedProtocolMessageType('GcsEntry', (_message.Message,), {
  'DESCRIPTOR' : _GCSENTRY,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsEntry)
  })
_sym_db.RegisterMessage(GcsEntry)

ObjectTableData = _reflection.GeneratedProtocolMessageType('ObjectTableData', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ObjectTableData)
  })
_sym_db.RegisterMessage(ObjectTableData)

TaskReconstructionData = _reflection.GeneratedProtocolMessageType('TaskReconstructionData', (_message.Message,), {
  'DESCRIPTOR' : _TASKRECONSTRUCTIONDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TaskReconstructionData)
  })
_sym_db.RegisterMessage(TaskReconstructionData)

TaskTableData = _reflection.GeneratedProtocolMessageType('TaskTableData', (_message.Message,), {
  'DESCRIPTOR' : _TASKTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TaskTableData)
  })
_sym_db.RegisterMessage(TaskTableData)

ActorTableData = _reflection.GeneratedProtocolMessageType('ActorTableData', (_message.Message,), {
  'DESCRIPTOR' : _ACTORTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ActorTableData)
  })
_sym_db.RegisterMessage(ActorTableData)

ErrorTableData = _reflection.GeneratedProtocolMessageType('ErrorTableData', (_message.Message,), {
  'DESCRIPTOR' : _ERRORTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ErrorTableData)
  })
_sym_db.RegisterMessage(ErrorTableData)

ScheduleData = _reflection.GeneratedProtocolMessageType('ScheduleData', (_message.Message,), {

  'SchedulePlanEntry' : _reflection.GeneratedProtocolMessageType('SchedulePlanEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCHEDULEDATA_SCHEDULEPLANENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ScheduleData.SchedulePlanEntry)
    })
  ,
  'DESCRIPTOR' : _SCHEDULEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ScheduleData)
  })
_sym_db.RegisterMessage(ScheduleData)
_sym_db.RegisterMessage(ScheduleData.SchedulePlanEntry)

ProfileTableData = _reflection.GeneratedProtocolMessageType('ProfileTableData', (_message.Message,), {

  'ProfileEvent' : _reflection.GeneratedProtocolMessageType('ProfileEvent', (_message.Message,), {
    'DESCRIPTOR' : _PROFILETABLEDATA_PROFILEEVENT,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ProfileTableData.ProfileEvent)
    })
  ,
  'DESCRIPTOR' : _PROFILETABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ProfileTableData)
  })
_sym_db.RegisterMessage(ProfileTableData)
_sym_db.RegisterMessage(ProfileTableData.ProfileEvent)

ResourceTableData = _reflection.GeneratedProtocolMessageType('ResourceTableData', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceTableData)
  })
_sym_db.RegisterMessage(ResourceTableData)

AvailableResources = _reflection.GeneratedProtocolMessageType('AvailableResources', (_message.Message,), {

  'ResourcesAvailableEntry' : _reflection.GeneratedProtocolMessageType('ResourcesAvailableEntry', (_message.Message,), {
    'DESCRIPTOR' : _AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.AvailableResources.ResourcesAvailableEntry)
    })
  ,
  'DESCRIPTOR' : _AVAILABLERESOURCES,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AvailableResources)
  })
_sym_db.RegisterMessage(AvailableResources)
_sym_db.RegisterMessage(AvailableResources.ResourcesAvailableEntry)

GcsNodeInfo = _reflection.GeneratedProtocolMessageType('GcsNodeInfo', (_message.Message,), {
  'DESCRIPTOR' : _GCSNODEINFO,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsNodeInfo)
  })
_sym_db.RegisterMessage(GcsNodeInfo)

HeartbeatTableData = _reflection.GeneratedProtocolMessageType('HeartbeatTableData', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.HeartbeatTableData)
  })
_sym_db.RegisterMessage(HeartbeatTableData)

TaskLeaseData = _reflection.GeneratedProtocolMessageType('TaskLeaseData', (_message.Message,), {
  'DESCRIPTOR' : _TASKLEASEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TaskLeaseData)
  })
_sym_db.RegisterMessage(TaskLeaseData)

JobConfig = _reflection.GeneratedProtocolMessageType('JobConfig', (_message.Message,), {

  'WorkerEnvEntry' : _reflection.GeneratedProtocolMessageType('WorkerEnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOBCONFIG_WORKERENVENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.JobConfig.WorkerEnvEntry)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOBCONFIG_METADATAENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.JobConfig.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _JOBCONFIG,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.JobConfig)
  })
_sym_db.RegisterMessage(JobConfig)
_sym_db.RegisterMessage(JobConfig.WorkerEnvEntry)
_sym_db.RegisterMessage(JobConfig.MetadataEntry)

JobTableData = _reflection.GeneratedProtocolMessageType('JobTableData', (_message.Message,), {
  'DESCRIPTOR' : _JOBTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.JobTableData)
  })
_sym_db.RegisterMessage(JobTableData)

WorkerTableData = _reflection.GeneratedProtocolMessageType('WorkerTableData', (_message.Message,), {

  'WorkerInfoEntry' : _reflection.GeneratedProtocolMessageType('WorkerInfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _WORKERTABLEDATA_WORKERINFOENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.WorkerTableData.WorkerInfoEntry)
    })
  ,
  'DESCRIPTOR' : _WORKERTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.WorkerTableData)
  })
_sym_db.RegisterMessage(WorkerTableData)
_sym_db.RegisterMessage(WorkerTableData.WorkerInfoEntry)

WorkerDeltaData = _reflection.GeneratedProtocolMessageType('WorkerDeltaData', (_message.Message,), {
  'DESCRIPTOR' : _WORKERDELTADATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.WorkerDeltaData)
  })
_sym_db.RegisterMessage(WorkerDeltaData)

ResourceMap = _reflection.GeneratedProtocolMessageType('ResourceMap', (_message.Message,), {

  'ItemsEntry' : _reflection.GeneratedProtocolMessageType('ItemsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEMAP_ITEMSENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourceMap.ItemsEntry)
    })
  ,
  'DESCRIPTOR' : _RESOURCEMAP,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceMap)
  })
_sym_db.RegisterMessage(ResourceMap)
_sym_db.RegisterMessage(ResourceMap.ItemsEntry)

StoredConfig = _reflection.GeneratedProtocolMessageType('StoredConfig', (_message.Message,), {
  'DESCRIPTOR' : _STOREDCONFIG,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.StoredConfig)
  })
_sym_db.RegisterMessage(StoredConfig)

ObjectLocationInfo = _reflection.GeneratedProtocolMessageType('ObjectLocationInfo', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTLOCATIONINFO,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ObjectLocationInfo)
  })
_sym_db.RegisterMessage(ObjectLocationInfo)

ObjectLocationChange = _reflection.GeneratedProtocolMessageType('ObjectLocationChange', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTLOCATIONCHANGE,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ObjectLocationChange)
  })
_sym_db.RegisterMessage(ObjectLocationChange)

NodeResourceChange = _reflection.GeneratedProtocolMessageType('NodeResourceChange', (_message.Message,), {

  'UpdatedResourcesEntry' : _reflection.GeneratedProtocolMessageType('UpdatedResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODERESOURCECHANGE_UPDATEDRESOURCESENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.NodeResourceChange.UpdatedResourcesEntry)
    })
  ,
  'DESCRIPTOR' : _NODERESOURCECHANGE,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.NodeResourceChange)
  })
_sym_db.RegisterMessage(NodeResourceChange)
_sym_db.RegisterMessage(NodeResourceChange.UpdatedResourcesEntry)

PubSubMessage = _reflection.GeneratedProtocolMessageType('PubSubMessage', (_message.Message,), {
  'DESCRIPTOR' : _PUBSUBMESSAGE,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PubSubMessage)
  })
_sym_db.RegisterMessage(PubSubMessage)

ResourceUpdate = _reflection.GeneratedProtocolMessageType('ResourceUpdate', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEUPDATE,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceUpdate)
  })
_sym_db.RegisterMessage(ResourceUpdate)

ResourceUsageBroadcastData = _reflection.GeneratedProtocolMessageType('ResourceUsageBroadcastData', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEUSAGEBROADCASTDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceUsageBroadcastData)
  })
_sym_db.RegisterMessage(ResourceUsageBroadcastData)

ResourceDemand = _reflection.GeneratedProtocolMessageType('ResourceDemand', (_message.Message,), {

  'ShapeEntry' : _reflection.GeneratedProtocolMessageType('ShapeEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEDEMAND_SHAPEENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourceDemand.ShapeEntry)
    })
  ,
  'DESCRIPTOR' : _RESOURCEDEMAND,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceDemand)
  })
_sym_db.RegisterMessage(ResourceDemand)
_sym_db.RegisterMessage(ResourceDemand.ShapeEntry)

ResourceLoad = _reflection.GeneratedProtocolMessageType('ResourceLoad', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCELOAD,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceLoad)
  })
_sym_db.RegisterMessage(ResourceLoad)

ResourcesData = _reflection.GeneratedProtocolMessageType('ResourcesData', (_message.Message,), {

  'ResourcesAvailableEntry' : _reflection.GeneratedProtocolMessageType('ResourcesAvailableEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCESDATA_RESOURCESAVAILABLEENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourcesData.ResourcesAvailableEntry)
    })
  ,

  'ResourcesTotalEntry' : _reflection.GeneratedProtocolMessageType('ResourcesTotalEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCESDATA_RESOURCESTOTALENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourcesData.ResourcesTotalEntry)
    })
  ,

  'ResourceLoadEntry' : _reflection.GeneratedProtocolMessageType('ResourceLoadEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCESDATA_RESOURCELOADENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourcesData.ResourceLoadEntry)
    })
  ,

  'ResourcesNormalTaskEntry' : _reflection.GeneratedProtocolMessageType('ResourcesNormalTaskEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCESDATA_RESOURCESNORMALTASKENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourcesData.ResourcesNormalTaskEntry)
    })
  ,
  'DESCRIPTOR' : _RESOURCESDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourcesData)
  })
_sym_db.RegisterMessage(ResourcesData)
_sym_db.RegisterMessage(ResourcesData.ResourcesAvailableEntry)
_sym_db.RegisterMessage(ResourcesData.ResourcesTotalEntry)
_sym_db.RegisterMessage(ResourcesData.ResourceLoadEntry)
_sym_db.RegisterMessage(ResourcesData.ResourcesNormalTaskEntry)

ResourceUsageBatchData = _reflection.GeneratedProtocolMessageType('ResourceUsageBatchData', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEUSAGEBATCHDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceUsageBatchData)
  })
_sym_db.RegisterMessage(ResourceUsageBatchData)

PlacementGroupLoad = _reflection.GeneratedProtocolMessageType('PlacementGroupLoad', (_message.Message,), {
  'DESCRIPTOR' : _PLACEMENTGROUPLOAD,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PlacementGroupLoad)
  })
_sym_db.RegisterMessage(PlacementGroupLoad)

PlacementGroupTableData = _reflection.GeneratedProtocolMessageType('PlacementGroupTableData', (_message.Message,), {
  'DESCRIPTOR' : _PLACEMENTGROUPTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PlacementGroupTableData)
  })
_sym_db.RegisterMessage(PlacementGroupTableData)


DESCRIPTOR._options = None
_SCHEDULEDATA_SCHEDULEPLANENTRY._options = None
_AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY._options = None
_JOBCONFIG_WORKERENVENTRY._options = None
_JOBCONFIG_METADATAENTRY._options = None
_WORKERTABLEDATA_WORKERINFOENTRY._options = None
_RESOURCEMAP_ITEMSENTRY._options = None
_NODERESOURCECHANGE_UPDATEDRESOURCESENTRY._options = None
_RESOURCEDEMAND_SHAPEENTRY._options = None
_RESOURCESDATA_RESOURCESAVAILABLEENTRY._options = None
_RESOURCESDATA_RESOURCESTOTALENTRY._options = None
_RESOURCESDATA_RESOURCELOADENTRY._options = None
_RESOURCESDATA_RESOURCESNORMALTASKENTRY._options = None
# @@protoc_insertion_point(module_scope)
